==> parse-multi-instance-2.0.1.tgz: package/lib/react-native/Cloud.js <==
/**
 * Copyright (c) 2015-present, Parse, LLC.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 * 
 */

import { CoreManager, CoreManagerInstance } from './CoreManager';
import decode from './decode';
import encode from './encode';
import ParseError from './ParseError';
import ParsePromise from './ParsePromise';

/**
 * Contains functions for calling and declaring
 * <a href="/docs/cloud_code_guide#functions">cloud functions</a>.
 * <p><strong><em>
 *   Some functions are only available from Cloud Code.
 * </em></strong></p>
 *
 * @class Parse.Cloud
 * @static
 * @hideconstructor
 */

/**
 * Makes a call to a cloud function.
 * @method run
 * @name Parse.Cloud.run
 * @param {String} name The function name.
 * @param {Object} data The parameters to send to the cloud function.
 * @param {Object} options A Backbone-style options object
 * options.success, if set, should be a function to handle a successful
 * call to a cloud function.  options.error should be a function that
 * handles an error running the cloud function.  Both functions are
 * optional.  Both functions take a single argument.
 * @return {Parse.Promise} A promise that will be resolved with the result
 * of the function.
 */

export default class ParseCloudFacade {
  constructor(coreManager) {
    this._CoreManager = coreManager;
    this._CoreManager.setCloudFacade(this);
    this._CoreManager.setCloudController(new DefaultController(this._CoreManager));
  }

  run(name, data, options) {
    options = options || {};

    if (typeof name !== 'string' || name.length === 0) {
      throw new TypeError('Cloud function name must be a string.');
    }

    var requestOptions = {};
    if (options.useMasterKey) {
      requestOptions.useMasterKey = options.useMasterKey;
    }
    if (options.sessionToken) {
      requestOptions.sessionToken = options.sessionToken;
    }

    return this._CoreManager.getCloudController().run(name, data, requestOptions)._thenRunCallbacks(options);
  }
}

class DefaultController {
  constructor(coreManager) {
    this._CoreManager = coreManager;
  }

  run(name, data, options) {
    var RESTController = this._CoreManager.getRESTController();

    var payload = encode(data, true);

    var requestOptions = {};
    if (options.hasOwnProperty('useMasterKey')) {
      requestOptions.useMasterKey = options.useMasterKey;
    }
    if (options.hasOwnProperty('sessionToken')) {
      requestOptions.sessionToken = options.sessionToken;
    }

    var request = RESTController.request('POST', 'functions/' + name, payload, requestOptions);

    return request.then(function (res) {
      var decoded = decode(res, this._CoreManager);
      if (decoded && decoded.hasOwnProperty('result')) {
        return ParsePromise.as(decoded.result);
      }
      return ParsePromise.error(new ParseError(ParseError.INVALID_JSON, 'The server returned an invalid response.'));
    })._thenRunCallbacks(options);
  }
}

const _ParseCloudFacase = new ParseCloudFacade(CoreManager);

==> parse-multi-instance-2.0.2.tgz: package/lib/react-native/Cloud.js <==
/**
 * Copyright (c) 2015-present, Parse, LLC.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 * 
 */

import { CoreManager, CoreManagerInstance } from './CoreManager';
import decode from './decode';
import encode from './encode';
import ParseError from './ParseError';
import ParsePromise from './ParsePromise';

/**
 * Contains functions for calling and declaring
 * <a href="/docs/cloud_code_guide#functions">cloud functions</a>.
 * <p><strong><em>
 *   Some functions are only available from Cloud Code.
 * </em></strong></p>
 *
 * @class Parse.Cloud
 * @static
 * @hideconstructor
 */

/**
 * Makes a call to a cloud function.
 * @method run
 * @name Parse.Cloud.run
 * @param {String} name The function name.
 * @param {Object} data The parameters to send to the cloud function.
 * @param {Object} options A Backbone-style options object
 * options.success, if set, should be a function to handle a successful
 * call to a cloud function.  options.error should be a function that
 * handles an error running the cloud function.  Both functions are
 * optional.  Both functions take a single argument.
 * @return {Parse.Promise} A promise that will be resolved with the result
 * of the function.
 */

export default class ParseCloudFacade {
  constructor(coreManager) {
    this._CoreManager = coreManager;
    this._CoreManager.setCloudFacade(this);
    this._CoreManager.setCloudController(new DefaultController(this._CoreManager));
  }

  run(name, data, options) {
    options = options || {};

    if (typeof name !== 'string' || name.length === 0) {
      throw new TypeError('Cloud function name must be a string.');
    }

    var requestOptions = {};
    if (options.useMasterKey) {
      requestOptions.useMasterKey = options.useMasterKey;
    }
    if (options.sessionToken) {
      requestOptions.sessionToken = options.sessionToken;
    }

    return this._CoreManager.getCloudController().run(name, data, requestOptions)._thenRunCallbacks(options);
  }
}

class DefaultController {
  constructor(coreManager) {
    this._CoreManager = coreManager;
  }

  run(name, data, options) {
    var RESTController = this._CoreManager.getRESTController();

    var payload = encode(data, true);

    var requestOptions = {};
    if (options.hasOwnProperty('useMasterKey')) {
      requestOptions.useMasterKey = options.useMasterKey;
    }
    if (options.hasOwnProperty('sessionToken')) {
      requestOptions.sessionToken = options.sessionToken;
    }

    var request = RESTController.request('POST', 'functions/' + name, payload, requestOptions);

    return request.then(res => {
      var decoded = decode(res, this._CoreManager);
      if (decoded && decoded.hasOwnProperty('result')) {
        return ParsePromise.as(decoded.result);
      }
      return ParsePromise.error(new ParseError(ParseError.INVALID_JSON, 'The server returned an invalid response.'));
    })._thenRunCallbacks(options);
  }
}

const _ParseCloudFacase = new ParseCloudFacade(CoreManager);
